@@ -16,9 +16,12 @@ import numpy as np
 import scipy as sp
 
 import scqubits.core.operators as op
-from scqubits.core.spectrum import WaveFunction
+from scqubits.core.constants import MODE_STR_DICT
+from scqubits.core.descriptors import WatchedProperty
+from scqubits.core.discretization import Grid1d
 from scqubits.core.harmonic_osc import harm_osc_wavefunction
 from scqubits.core.qubit_base import QubitBaseClass1d
+from scqubits.core.storage import WaveFunction
 
 
 # —Fluxonium qubit ————————————————————————
@@ -47,6 +50,12 @@ class Fluxonium(QubitBaseClass1d):
         desired dimension of the truncated quantum system
     """
 
+    EJ = WatchedProperty('QUANTUMSYSTEM_UPDATE')
+    EC = WatchedProperty('QUANTUMSYSTEM_UPDATE')
+    EL = WatchedProperty('QUANTUMSYSTEM_UPDATE')
+    flux = WatchedProperty('QUANTUMSYSTEM_UPDATE')
+    cutoff = WatchedProperty('QUANTUMSYSTEM_UPDATE')
+
     def __init__(self, EJ, EC, EL, flux, cutoff, truncated_dim=None):
         self.EJ = EJ
         self.EC = EC
@@ -56,8 +65,7 @@ class Fluxonium(QubitBaseClass1d):
         self.truncated_dim = truncated_dim
         self._sys_type = 'fluxonium'
         self._evec_dtype = np.float_
-        self._default_var_range = (-4.5*np.pi, 4.5*np.pi)
-        self._default_var_count = 151
+        self._default_grid = Grid1d(-4.5*np.pi, 4.5*np.pi, 151)
 
     def phi_osc(self):
         """
@@ -169,7 +177,7 @@ class Fluxonium(QubitBaseClass1d):
         """
         return 0.5 * self.EL * phi * phi - self.EJ * np.cos(phi + 2.0 * np.pi * self.flux)
 
-    def wavefunction(self, esys, which=0, phi_range=None, phi_count=None):
+    def wavefunction(self, esys, which=0, phi_grid=None):
         """Returns a fluxonium wave function in `phi` basis
 
         Parameters
@@ -178,10 +186,8 @@ class Fluxonium(QubitBaseClass1d):
             eigenvalues, eigenvectors
         which: int, optional
              index of desired wave function (default value = 0)
-        phi_range: tuple(float,float), optional
-             custom boundaries of `phi` values range
-        phi_count: int
-             number of points in the specified `phi` interval
+        phi_grid: Grid1d, optional
+            used for setting a custom grid for phi; if None use self._default_grid
 
         Returns
         -------
@@ -194,13 +200,37 @@ class Fluxonium(QubitBaseClass1d):
             evals, evecs = esys
         dim = self.hilbertdim()
 
-        phi_range, phi_count = self._try_defaults(phi_range, phi_count)
+        phi_grid = phi_grid or self._default_grid
 
-        phi_basis_labels = np.linspace(phi_range[0], phi_range[1], phi_count)
+        phi_basis_labels = phi_grid.make_linspace()
         wavefunc_osc_basis_amplitudes = evecs[:, which]
-        phi_wavefunc_amplitudes = np.zeros(phi_count, dtype=np.complex_)
+        phi_wavefunc_amplitudes = np.zeros(phi_grid.pt_count, dtype=np.complex_)
         phi_osc = self.phi_osc()
         for n in range(dim):
             phi_wavefunc_amplitudes += wavefunc_osc_basis_amplitudes[n] * harm_osc_wavefunction(n, phi_basis_labels,
                                                                                                 phi_osc)
         return WaveFunction(basis_labels=phi_basis_labels, amplitudes=phi_wavefunc_amplitudes, energy=evals[which])
+
+    def wavefunction1d_defaults(self, mode, evals, wavefunc_count):
+        """Plot defaults for plotting.wavefunction1d.
+
+        Parameters
+        ----------
+        mode: str
+            amplitude modifier, needed to give the correct default y label
+        evals: ndarray
+            eigenvalues to include in plot
+        wavefunc_count: int
+            number of wave functions to be plotted
+        """
+        ylabel = r'$\psi_j(\varphi)$'
+        ylabel = MODE_STR_DICT[mode](ylabel)
+        options = {
+            'xlabel': r'$\varphi$',
+            'ylabel': ylabel
+        }
+        if wavefunc_count > 1:
+            ymin = - 1.025 * self.EJ
+            ymax = max(1.8 * self.EJ, evals[-1] + 0.1 * (evals[-1] - evals[0]))
+            options['ylim'] = (ymin, ymax)
+        return options
